<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Προσαρμογή Conky - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Εκκίνηση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Αναίρεση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Χρώματα</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Χρώμα0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Χρώμα1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Χρώμα2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Χρώμα3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Χρώμα4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Χρώμα5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Χρώμα6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Χρώμα7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Χρώμα8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Χρώμα9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="691"/>
        <source>Select Color</source>
        <translation>Επιλογή χρώματος</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="797"/>
        <source>Permission Denied</source>
        <translation>Απόρριψη άδειας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="798"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Δεν είναι δυνατή η εγγραφή στο αρχείο: %1
Ανεπαρκή δικαιώματα.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="808"/>
        <source>Write Error</source>
        <translation>Σφάλμα εγγραφής</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="808"/>
        <source>Cannot write to file: %1</source>
        <translation>Δεν είναι δυνατή η εγγραφή στο αρχείο: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="881"/>
        <source>Backup Config File</source>
        <translation>Αντίγραφο ασφαλείας του αρχείου ρυθμίσεων</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="881"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Θέλετε να διατηρήσετε το αρχικό αρχείο;</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="904"/>
        <source>Backed Up Config File</source>
        <translation>Δημιουργία αντιγράφου ασφαλείας του αρχείου ρυθμίσεων</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="905"/>
        <source>The original configuration was backed up to %1</source>
        <translation>Η αρχική διαμόρφωση αποθηκεύτηκε στο %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="907"/>
        <source>Backup Failed</source>
        <translation>Το αντίγραφο ασφαλείας απέτυχε</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="907"/>
        <source>Failed to create a backup file.</source>
        <translation>Απέτυχε η δημιουργία αντιγράφου ασφαλείας.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="980"/>
        <location filename="../src/conkycustomizedialog.cpp" line="983"/>
        <source>Restore Failed</source>
        <translation>Η επαναφορά απέτυχε</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="980"/>
        <source>Failed to restore from backup file.</source>
        <translation>Απέτυχε η επαναφορά του αντιγράφου ασφαλείας.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="983"/>
        <source>Backup file does not exist.</source>
        <translation>Το αντίγραφο ασφαλείας δεν υπάρχει.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
        <source>Position</source>
        <translation>Θέση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
        <source>Alignment</source>
        <translation>Περιοχή</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
        <source>Top Left</source>
        <translation>Επάνω αριστερά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
        <source>Top Right</source>
        <translation>Επάνω δεξιά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1349"/>
        <source>Top Middle</source>
        <translation>Επάνω στη μέση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1350"/>
        <source>Bottom Left</source>
        <translation>Κάτω αριστερά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1351"/>
        <source>Bottom Right</source>
        <translation>Κάτω δεξιά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1352"/>
        <source>Bottom Middle</source>
        <translation>Κάτω στη μέση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
        <source>Middle Left</source>
        <translation>Στο κέντρο αριστερά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
        <source>Middle Right</source>
        <translation>Στο κέντρο δεξιά</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1355"/>
        <source>Middle Middle</source>
        <translation>Στο κέντρο στη μέση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1360"/>
        <source>Horizontal Gap</source>
        <translation>Οριζόντιο κενό</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1361"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Οριζόντια απόσταση από το περίγραμμα του παραθύρου (σε pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1373"/>
        <source>Vertical Gap</source>
        <translation>Κάθετο κενό</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1374"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Κάθετη απόσταση από το περίγραμμα του παραθύρου (σε pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1386"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1389"/>
        <source>Desktop 1</source>
        <translation>Επιφάνεια εργασίας 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1390"/>
        <source>All Desktops</source>
        <translation>Όλες οι επιφάνειες εργασίας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1402"/>
        <source>Location</source>
        <translation>Τοποθέτιση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1414"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Το πλάτος πρέπει να είναι μεγαλύτερο από το μέγεθος περιεχομένων του παραθύρου,
διαφορετικά η ρύθμιση αυτή δεν θα έχει κανένα αποτέλεσμα</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1418"/>
        <source>Minimum Width</source>
        <translation>Ελάχιστο πλάτος</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1433"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Το ύψος πρέπει να είναι μεγαλύτερο από το μέγεθος περιεχομένων του παραθύρου,
διαφορετικά η ρύθμιση αυτή δεν θα έχει κανένα αποτέλεσμα</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1435"/>
        <source>Minimum Height</source>
        <translation>Ελάχιστο ύψος</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1449"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Αυξάνει το ύψος του παραθύρου, προσθέτοντας κενές γραμμές στο τέλος του αρχείου ρυθμίσεων του Conky</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1450"/>
        <source>Height Padding</source>
        <translation>Συμπλήρωμα ύψους</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1465"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
        <source>Transparency Type</source>
        <translation>Τύπος διαφάνειας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1483"/>
        <source>Opaque</source>
        <translation>Αδιαφανές</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Transparent</source>
        <translation>Διαφανές</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
        <source>Pseudo-Transparent</source>
        <translation>Ψευδο-διαφανές</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1486"/>
        <source>Semi-Transparent</source>
        <translation>Ημι-διαφανές</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1491"/>
        <source>Opacity (%)</source>
        <translation>Αδιαφάνεια (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1492"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Αδιαφάνεια παραθύρου

0 = Πλήρως διαφανές, 100 = Πλήρως αδιαφανές</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1506"/>
        <source>Background Color</source>
        <translation>Χρώμα φόντου</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1511"/>
        <source>Choose Color</source>
        <translation>Επιλογή χρώματος</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1531"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Επιλέγοντας &quot;Διαφανές&quot; όλο το παράθυρο θα γίνει διαφανές (μαζί και τα εικονίδια). Χρησιμοποιήστε την επιλογή &quot;Ψευδο-διαφανές&quot; αν θέλετε τα εικονίδια να είναι αδιαφανή.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1541"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Επιλέγοντας &quot;Ψευδο-διαφανές&quot; το παράθυρο θα γίνει διαφανές, αλλά θα έχει σκιά. Η σκιά μπορεί να απενεργοποιηθεί ρυθμίζοντας τον διαχειριστή παραθύρων.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1552"/>
        <source>Transparency</source>
        <translation>Διαφάνεια</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1563"/>
        <source>Date Format</source>
        <translation>Μορφή ημερομηνίας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1566"/>
        <source>Day</source>
        <translation>Ημέρα</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1568"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1579"/>
        <source>Long</source>
        <translation>Πλήρης</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1569"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1580"/>
        <source>Short</source>
        <translation>Σύντομο</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1570"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Σύντομο όνομα, π.χ. Tρ</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1577"/>
        <source>Month</source>
        <translation>Μήνας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1581"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Σύντομο όνομα, π.χ. Οκτ</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1600"/>
        <source>Time Format</source>
        <translation>Μορφή ώρας</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1607"/>
        <source>Format</source>
        <translation>Μορφή</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1612"/>
        <source>12 Hour</source>
        <translation>12 ώρες</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1613"/>
        <source>24 Hour</source>
        <translation>24 ώρες</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1628"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Ημερομηνία &amp;&amp; Ώρα</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1641"/>
        <source>Interface</source>
        <translation>Διασύνδεση</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1649"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1652"/>
        <source>WiFi Network</source>
        <translation>Δίκτυο WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1655"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1658"/>
        <source>Wired LAN Network</source>
        <translation>Ενσύρματο δίκτυο LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1672"/>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1935"/>
        <source>Select Background Color</source>
        <translation>Επιλογή χρώματος φόντου</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Σε εκκίνηση</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Σε διακοπή</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Αυτόματη έναρξη</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Προσαρμογή</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Συνολικά: 0 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Total: %1 conkies</source>
        <translation>Συνολικά: %1 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="601"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Εμφάνιση: %1 από %2 conkies</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="550"/>
        <source>No Conky Selected</source>
        <translation>Δεν επιλέχτηκε conky</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="552"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Επιλέξτε ένα conky από τη λίστα για να δείτε τη προεπισκόπηση του</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>Preview image could not be loaded</source>
        <translation>Δεν ήταν δυνατή η φόρτωση της εικόνας προεπισκόπησης</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="574"/>
        <source>No preview image available</source>
        <translation>Δεν υπάρχει διαθέσιμη εικόνα προεπισκόπησης</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="57"/>
        <location filename="../src/mainwindow.cpp" line="829"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="249"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="247"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="254"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="269"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="267"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>Loading Conky configurations...</source>
        <translation>Φόρτωση ρυθμίσεων conky...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>Configure conky search paths</source>
        <translation>Ρύθμιση διαδρομών αναζήτησης</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="191"/>
        <source>Refresh</source>
        <translation>Ανανέωση</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="193"/>
        <source>Refresh conky list</source>
        <translation>Ανανέωση λίστας</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="195"/>
        <source>Start All</source>
        <translation>Έναρξη όλων</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="197"/>
        <source>Start all enabled conkies</source>
        <translation>&apos;Εναρξη όλων των ενεργοποιημένων</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="199"/>
        <source>Stop All</source>
        <translation>Διακοπή όλων</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="201"/>
        <source>Stop all running conkies</source>
        <translation>Διακοπή όλων των διεργασιών</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="931"/>
        <location filename="../src/mainwindow.cpp" line="970"/>
        <source>Running</source>
        <translation>Σε εκκίνηση</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <location filename="../src/mainwindow.cpp" line="971"/>
        <source>Stopped</source>
        <translation>Σε διακοπή</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="209"/>
        <source>Search conky by name...</source>
        <translation>Αναζήτηση με όνομα...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="211"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Αναζήτηση conkies με όνομα (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="256"/>
        <source>Display help</source>
        <translation>Εμφάνιση βοήθειας</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <location filename="../src/mainwindow.cpp" line="608"/>
        <source>Copy Conky</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="478"/>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky Copied</source>
        <translation>Το conky αντιγράφηκε</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Το conky αντιγράφηκε στο προσωπικό σας φάκελο για επεξεργασία:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Copy Failed</source>
        <translation>Η αντιγραφή απέτυχε</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Απέτυχε η αντιγραφή του conky στο προσωπικό σας φάκελο.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="543"/>
        <source>Delete Conky</source>
        <translation>Διαγραφή conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="657"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Το conky αντιγράφηκε στο προσωπικό σας φάκελο για προσαρμογή:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Delete Successful</source>
        <translation>Επιτυχής διαγραφή</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>Previews</source>
        <translation>Προεπισκοπίσεις</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Generate preview images for conkies</source>
        <translation>Δημιουργία εικόνων προεπισκόπησης</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <location filename="../src/mainwindow.cpp" line="929"/>
        <location filename="../src/mainwindow.cpp" line="969"/>
        <source>All</source>
        <translation>Όλα</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <source>Filter conkies by running status or location</source>
        <translation>Εμφάνιση με βάση τη κατάσταση λειτουργίας ή τη τοποθεσία</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="428"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Enter a name for the copy:</source>
        <translation>Εισαγωγή ονόματος για το αντίγραφο:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="605"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Για να μπορέσετε να επεξεργαστείτε και να αποθηκεύσετε το conky, πρέπει πρώτα να το αντιγράψετε στο ~/.conky όπου έχετε τα δικαιώματα.
Εισαγωγή ονόματος για το αντίγραφο.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>Directory Exists</source>
        <translation>Ο κατάλογος υπάρχει</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Υπάρχει ήδη conky με όνομα &apos;%1&apos; στο προσωπικό σας φάκελο.
Θέλετε να το αντικαταστήσω;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>Edit Conky</source>
        <translation>Επεξεργασία conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Αυτό το αρχείο conky είναι μόνο για ανάγνωση και απαιτεί δικαιώματα διαχειριστή για επεξεργασία του.
Θέλετε να το επεξεργαστείτε με αυξημένα δικαιώματα;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Θέλετε σίγουρα να διαγράψετε το αρχείο conky:
%1

Αυτή ενέργεια δεν μπορεί να αναιρεθεί.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Conky file deleted successfully.</source>
        <translation>Το αρχείο conky διαγράφηκε με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Delete Failed</source>
        <translation>Η διαγραφή απέτυχε</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Απέτυχε η διαγραφή του αρχείου conky:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>Customize Conky</source>
        <translation>Προσαρμογή conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="667"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Αυτό το αρχείο conky είναι μόνο για ανάγνωση και απαιτεί δικαιώματα διαχειριστή για τη προσαρμογή του.
Θέλετε να προχωρήσετε σε προσαρμογή με αυξημένα δικαιώματα;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Editor Error</source>
        <translation>Σφάλμα επεξεργασίας</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Δεν είναι δυνατή η εκκίνηση του επεξεργαστή για το αρχείο: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="828"/>
        <source>About MX Conky</source>
        <translation>Περί του MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="830"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="831"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Γραφικό πρόγραμμα για τη διαμόρφωση του Conky στο MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c)  MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="836"/>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="837"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="859"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="890"/>
        <source>MX Conky Help</source>
        <translation>Βοήθεια του MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="935"/>
        <location filename="../src/mainwindow.cpp" line="972"/>
        <source>Autostart</source>
        <translation>Αυτόματη έναρξη</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Δημιουργία προεπισκόπησης</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Δημιουργία προεπισκόπησης εικόνων για</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Τα επιλεγμένα</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Όλα στα οποία λείπουν</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Όλα (Με αντικατάσταση των εικόνων)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Δεν είναι επιλεγμένο κάποιο conky</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Εικόνες υψηλής ποιότητας (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Δημιουργία προεπισκόπησης εικόνων σε μορφή PNG αντί για JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Δεν υπάρχουν αντικείμενα</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Δεν απαιτείται δημιουργία προεπισκόπησης για τα conky.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="155"/>
        <source>Starting preview generation...</source>
        <translation>Έναρξη δημιουργίας προεπισκόπησης...</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="159"/>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="198"/>
        <source>Generating preview for: %1</source>
        <translation>Δημιουργία προεπισκόπησης για: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="419"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Ολοκληρώθηκε η δημιουργία προεπισκόπησης. Δημιουργήθηκαν %1.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="423"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="426"/>
        <source>Preview Generation Complete</source>
        <translation>Ολοκληρώθηκε η δημιουργία προεπισκόπησης</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>Δημιουργήθηκαν %1 εικόνες προεπισκόπησης με επιτυχία.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Επιλογή αρχείου διαμόρφωσης του Conky Manager</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Πρέπει να εκτελέσετε αυτή την εφαρμογή ως απλός χρήστης</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Επιλογή καταλόγου conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>MX Ρυθμίσεις conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Διαδρομές αναζήτησης</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Αυτόματη έναρξη</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Διαδρομές αναζήτησης για conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Ρυθμίσεις αυτόματης έναρξης</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>&apos;Εναρξη conky με την εκκίνηση του συστήματος</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Καθυστέρηση έναρξης (σε δευτερόλεπτα):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
</context>
</TS>